==> visual-third-party-1.3.7-ibk-sources.jar: com/tenqube/visual_third/MainActivity.java <==
package com.tenqube.visual_third;

import android.Manifest;
import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.support.v4.content.LocalBroadcastManager;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CompoundButton;
import android.widget.LinearLayout;
import android.widget.Switch;

import com.tenqube.visual_third.exception.AuthException;
import com.tenqube.visual_third.exception.ParameterException;
import com.tenqube.visual_third.model.parser.PopupData;
import com.tenqube.visual_third.ui.OnResultListener;
import com.tenqube.visual_third.ui.VisualWebActivity;

import static com.tenqube.visual_third.Constants.ACTION_TRAN_POPUP;
import static com.tenqube.visual_third.Constants.INTENT_POPUP_KEY;


public class MainActivity extends Activity {

    private VisualService visualService;
    private LinearLayout container;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        try {
            // visual service 생성
            visualService = new VisualServiceImpl(this,
                    "LEZQmdU1Zx8hxH1PjfT7hWTzdGOQYre58AVHNgA0",
                    Constants.DEV,
                    BuildConfig.APPLICATION_ID);
            visualService.setLogger(true); // 개발자 모드 설정 (로그 확인이 가능합니다.)

            // 알림 상태바에 나타느는 notification small icon 값 설정
            visualService.settingNotification(R.drawable.ic_deposit_loan, "1234", 0); // 상단 노티 아이콘 설정

            // 팝업 설정
            Switch popup = (Switch) findViewById(R.id.popup);
            popup.setChecked(visualService.isActiveTranPopup());
            popup.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
                @Override
                public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                    visualService.setTranPopup(isChecked);
                }
            });

            // daily 알림 설정
            Switch daily = (Switch) findViewById(R.id.daily);
            daily.setChecked(visualService.isActiveDailyNoti());
            daily.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
                @Override
                public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {

                    visualService.setDailyNoti(isChecked);
                }
            });

            // weekly 알림 설정
            Switch weekly = (Switch) findViewById(R.id.weekly);
            weekly.setChecked(visualService.isActiveWeeklyNoti());

            weekly.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
                @Override
                public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                    visualService.setWeeklyNoti(isChecked);
                }
            });

            // monthly 알림설정
            Switch monthly = (Switch) findViewById(R.id.monthly);
            monthly.setChecked(visualService.isActiveMonthlyNoti());
            monthly.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
                @Override
                public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                    visualService.setMonthlyNoti(isChecked);
                }
            });

            IntentFilter filter = new IntentFilter();
            filter.addAction(ACTION_TRAN_POPUP);
            LocalBroadcastManager.getInstance(getApplicationContext()).registerReceiver(new TranReceiver(), filter);

            container = (LinearLayout) findViewById(R.id.adContainer);

            findViewById(R.id.ad).setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {

                    visualService.signOut(new Callback() {
                        @Override
                        public void onDataLoaded(Object value) {

                        }
                    });
//                    AdManager.getInstance(getApplicationContext()).loadAd(new OnAdLoadedListener() {
//                        @Override
//                        public void onAdLoaded(View view) {
//                            container.removeAllViews();
//                            if(view.getParent() != null) {
//                                ((ViewGroup)view.getParent()).removeView(view);
//                            }
//                            container.addView(view);
//
//
//                        }
//                    });
                }
            });

        } catch (ParameterException e) {
            e.printStackTrace();
        }


    }

    public class TranReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(final Context context, Intent intent) {

            if(ACTION_TRAN_POPUP.equals(intent.getAction())) {
                Bundle bundle = intent.getBundleExtra(INTENT_POPUP_KEY);

                if(bundle != null) {
                    PopupData popupData = (PopupData) bundle.getSerializable(INTENT_POPUP_KEY);
                    try {
                        VisualWebActivity.startActivity(context, popupData);
                    } catch (AuthException e) {
                        e.printStackTrace();
                    } catch (ParameterException e) {
                        e.printStackTrace();
                    }

                    if(popupData != null) {
                        container.removeAllViews();
                        if(popupData.getAdView().getParent() != null) {
                            ((ViewGroup)popupData.getAdView().getParent()).removeView(popupData.getAdView());
                        }
                        container.addView(popupData.getAdView());
                    }
                }
            }
        }

    }

//    /**
//     * 1. 맨처음 가입 이후 파싱 진행 가능
//     * 2. 가입 실패시
//     * @param view
//     */
//    public void onSignUp(View view) {
//
////    }
////        visualService.getAdView(new OnAdLoadedListener() {
////            @Override
////            public void onAdLoaded(final View ad) {
////                adView.post(new Runnable() {
////                    @Override
////                    public void run() {
////                        adView.addView(ad);
////                        adView.invalidate();
////                    }
////                });
////
////            }
////        });
//    }

    /**
     *
     * @param view
     */
    public void onWeb(View view) {

        try {
            if (ContextCompat.checkSelfPermission(MainActivity.this,
                    Manifest.permission.READ_SMS)
                    != PackageManager.PERMISSION_GRANTED) {

                // Should we show an explanation?
                if (ActivityCompat.shouldShowRequestPermissionRationale(MainActivity.this,
                        Manifest.permission.READ_SMS)) {



                } else {

                    ActivityCompat.requestPermissions(MainActivity.this,
                            new String[]{Manifest.permission.READ_SMS, Manifest.permission.RECEIVE_SMS},
                            0);

                }
            } else {
                visualService.startVisual(MainActivity.this, "1234", "", new OnResultListener() {
                    @Override
                    public void onResult(int signUpResult, String msg) {

                    }
                });
            }


        } catch (SecurityException e) {
            e.printStackTrace();
        } catch (ParameterException e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode,
                                           String permissions[], int[] grantResults) {
        switch (requestCode) {
            case 0: {
                // If request is cancelled, the result arrays are empty.
                if (grantResults.length > 0
                        && grantResults[0] == PackageManager.PERMISSION_GRANTED) {

                    try {
                        visualService.startVisual(MainActivity.this, "1234", "", new OnResultListener() {
                            @Override
                            public void onResult(int signUpResult, String msg) {

                            }
                        });
                    } catch (ParameterException e) {
                        e.printStackTrace();
                    }
                    // permission was granted, yay! Do the
                    // contacts-related task you need to do.

                } else {

                    // permission denied, boo! Disable the
                    // functionality that depends on this permission.
                }
                return;
            }

        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
    }
}

==> visual-third-party-1.4.3-ibk-sources.jar: com/tenqube/visual_third/MainActivity.java <==
package com.tenqube.visual_third;

import android.Manifest;
import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.support.v4.content.LocalBroadcastManager;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CompoundButton;
import android.widget.LinearLayout;
import android.widget.Switch;

import com.tenqube.visual_third.exception.AuthException;
import com.tenqube.visual_third.exception.ParameterException;
import com.tenqube.visual_third.model.parser.PopupData;
import com.tenqube.visual_third.ui.OnResultListener;
import com.tenqube.visual_third.ui.VisualWebActivity;

import static com.tenqube.visual_third.Constants.ACTION_TRAN_POPUP;
import static com.tenqube.visual_third.Constants.INTENT_POPUP_KEY;


public class MainActivity extends Activity {

    private VisualService visualService;
    private LinearLayout container;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        try {
            // visual service 생성
            visualService = new VisualServiceImpl(this,
                    "LEZQmdU1Zx8hxH1PjfT7hWTzdGOQYre58AVHNgA0",
                    Constants.DEV,
                    BuildConfig.APPLICATION_ID);
            visualService.setLogger(true); // 개발자 모드 설정 (로그 확인이 가능합니다.)

            // 알림 상태바에 나타느는 notification small icon 값 설정
            visualService.settingNotification(R.drawable.ic_deposit_loan, "1234", 0); // 상단 노티 아이콘 설정

            // 팝업 설정
            Switch popup = (Switch) findViewById(R.id.popup);
            popup.setChecked(visualService.isActiveTranPopup());
            popup.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
                @Override
                public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                    visualService.setTranPopup(isChecked);
                }
            });

            // daily 알림 설정
            Switch daily = (Switch) findViewById(R.id.daily);
            daily.setChecked(visualService.isActiveDailyNoti());
            daily.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
                @Override
                public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {

                    visualService.setDailyNoti(isChecked);
                }
            });

            // weekly 알림 설정
            Switch weekly = (Switch) findViewById(R.id.weekly);
            weekly.setChecked(visualService.isActiveWeeklyNoti());

            weekly.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
                @Override
                public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                    visualService.setWeeklyNoti(isChecked);
                }
            });

            // monthly 알림설정
            Switch monthly = (Switch) findViewById(R.id.monthly);
            monthly.setChecked(visualService.isActiveMonthlyNoti());
            monthly.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
                @Override
                public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                    visualService.setMonthlyNoti(isChecked);
                }
            });

            IntentFilter filter = new IntentFilter();
            filter.addAction(ACTION_TRAN_POPUP);
            LocalBroadcastManager.getInstance(getApplicationContext()).registerReceiver(new TranReceiver(), filter);

            container = (LinearLayout) findViewById(R.id.adContainer);

            findViewById(R.id.ad).setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {

                    visualService.setReportTest(Constants.NotificationType.DAILY, 5);
//                    visualService.signOut(new Callback() {
//                        @Override
//                        public void onDataLoaded(Object value) {
//
//                        }
//                    });
//                    AdManager.getInstance(getApplicationContext()).loadAd(new OnAdLoadedListener() {
//                        @Override
//                        public void onAdLoaded(View view) {
//                            container.removeAllViews();
//                            if(view.getParent() != null) {
//                                ((ViewGroup)view.getParent()).removeView(view);
//                            }
//                            container.addView(view);
//
//
//                        }
//                    });
                }
            });

        } catch (ParameterException e) {
            e.printStackTrace();
        }


    }

    public class TranReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(final Context context, Intent intent) {

            if(ACTION_TRAN_POPUP.equals(intent.getAction())) {
                Bundle bundle = intent.getBundleExtra(INTENT_POPUP_KEY);

                if(bundle != null) {
                    PopupData popupData = (PopupData) bundle.getSerializable(INTENT_POPUP_KEY);
                    try {
                        VisualWebActivity.startActivity(context, popupData);
                    } catch (AuthException e) {
                        e.printStackTrace();
                    } catch (ParameterException e) {
                        e.printStackTrace();
                    }

                    if(popupData != null) {
                        container.removeAllViews();
                        if(popupData.getAdView().getParent() != null) {
                            ((ViewGroup)popupData.getAdView().getParent()).removeView(popupData.getAdView());
                        }
                        container.addView(popupData.getAdView());
                    }
                }
            }
        }

    }

//    /**
//     * 1. 맨처음 가입 이후 파싱 진행 가능
//     * 2. 가입 실패시
//     * @param view
//     */
//    public void onSignUp(View view) {
//
////    }
////        visualService.getAdView(new OnAdLoadedListener() {
////            @Override
////            public void onAdLoaded(final View ad) {
////                adView.post(new Runnable() {
////                    @Override
////                    public void run() {
////                        adView.addView(ad);
////                        adView.invalidate();
////                    }
////                });
////
////            }
////        });
//    }

    /**
     *
     * @param view
     */
    public void onWeb(View view) {

        try {
            if (ContextCompat.checkSelfPermission(MainActivity.this,
                    Manifest.permission.READ_SMS)
                    != PackageManager.PERMISSION_GRANTED) {

                // Should we show an explanation?
                if (ActivityCompat.shouldShowRequestPermissionRationale(MainActivity.this,
                        Manifest.permission.READ_SMS)) {



                } else {

                    ActivityCompat.requestPermissions(MainActivity.this,
                            new String[]{Manifest.permission.READ_SMS, Manifest.permission.RECEIVE_SMS},
                            0);

                }
            } else {
                visualService.startVisual(MainActivity.this, "1234", "", new OnResultListener() {
                    @Override
                    public void onResult(int signUpResult, String msg) {

                    }
                });
            }


        } catch (SecurityException e) {
            e.printStackTrace();
        } catch (ParameterException e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode,
                                           String permissions[], int[] grantResults) {
        switch (requestCode) {
            case 0: {
                // If request is cancelled, the result arrays are empty.
                if (grantResults.length > 0
                        && grantResults[0] == PackageManager.PERMISSION_GRANTED) {

                    try {
                        visualService.startVisual(MainActivity.this, "1234", "", new OnResultListener() {
                            @Override
                            public void onResult(int signUpResult, String msg) {

                            }
                        });
                    } catch (ParameterException e) {
                        e.printStackTrace();
                    }
                    // permission was granted, yay! Do the
                    // contacts-related task you need to do.

                } else {

                    // permission denied, boo! Disable the
                    // functionality that depends on this permission.
                }
                return;
            }

        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
    }
}
